@@ -14,6 +14,7 @@ try:
 except ImportError:
 	HAS_CAIRO = False
 
+VERSION = '1.5.1'
 TILE_BUFFER = 128
 IM_MONTAGE = 'montage'
 
@@ -171,8 +172,15 @@ def xml_vars(style, variables):
 		rstyle = rstyle + style[last:]
 	return rstyle
 
+def add_fonts(path):
+	if os.path.exists(path):
+		mapnik.register_fonts(path)
+	else:
+		raise Exception('The directory "{p}" does not exists'.format(p=path))
+
 if __name__ == "__main__":
-	parser = argparse.ArgumentParser(description='Tile-aware mapnik image renderer')
+	parser = argparse.ArgumentParser(description='Nik4 {}: Tile-aware mapnik image renderer'.format(VERSION))
+	parser.add_argument('--version', action='version', version='Nik4 {}'.format(VERSION))
 	parser.add_argument('-z', '--zoom', type=float, help='Target zoom level')
 	parser.add_argument('-p', '--ppi', '--dpi', type=float, help='Pixels per inch (alternative to scale)')
 	parser.add_argument('--factor', type=float, help='Scale factor (affects ppi, default=1)', default=1)
@@ -200,6 +208,7 @@ if __name__ == "__main__":
 	parser.add_argument('-f', '--format', dest='fmt', help='Target file format (by default looks at extension)')
 	parser.add_argument('--base', help='Base path for style file, in case it\'s piped to stdin')
 	parser.add_argument('--vars', nargs='*', help='List of variables (name=value) to substitute in style file (use ${name:default})')
+	parser.add_argument('--fonts', nargs='*', help='List of full path to directories containing fonts')
 	parser.add_argument('style', help='Style file for mapnik')
 	parser.add_argument('output', help='Resulting image file')
 	options = parser.parse_args()
@@ -314,6 +323,11 @@ if __name__ == "__main__":
 	mapnik.load_map_from_string(m, style_xml, False, style_path)
 	m.srs = p3857.params()
 
+	# register non-standard fonts
+	if options.fonts:
+		for f in options.fonts:
+			add_fonts(f)
+
 	# get bbox from layer extents
 	if options.fit:
 		bbox = layer_bbox(m, options.fit.split(','), bbox)
